@@ -868,6 +868,7 @@ try_query_fs_info (GVfsBackend *backend,
 {
   g_file_info_set_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE, "network");
   g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_FILESYSTEM_REMOTE, TRUE);
+  g_file_info_set_attribute_uint32 (info, G_FILE_ATTRIBUTE_FILESYSTEM_USE_PREVIEW, G_FILESYSTEM_PREVIEW_TYPE_NEVER);
   g_vfs_job_succeeded (G_VFS_JOB (job));
   return TRUE;
 }
@@ -901,14 +902,7 @@ g_vfs_backend_network_init (GVfsBackendNetwork *network_backend)
       network_backend->smb_settings = g_settings_new ("org.gnome.system.smb");
 
       current_workgroup = g_settings_get_string (network_backend->smb_settings, "workgroup");
-
-      if (current_workgroup == NULL ||
-          current_workgroup[0] == 0) 
-        /* it's okay if current_workgroup is null here, 
-         * it's checked before the NetworkFile is added anyway. */
-        network_backend->current_workgroup = NULL;
-      else 
-        network_backend->current_workgroup = current_workgroup;
+      network_backend->current_workgroup = current_workgroup;
 
       g_signal_connect (network_backend->smb_settings,
                         "change-event",
